'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const fs = require('fs');

const paths = [];
const imports = (...options) => {
  const importMap = {};
  const presetNames = [];
  for (const opt of options) {
    if (typeof opt == "string") {
      presetNames.push(opt);
      continue;
    }
    const { target, alias = "@", include = [], exclude = [], prefix = "", suffix = "" } = opt;
    include.push(...fs.readdirSync(`src/${target}`).filter((item) => !exclude.includes(item) && item.startsWith(prefix) && item.endsWith(suffix + ".ts")));
    for (const item of include) {
      const path = `src/${target}/${item}`;
      paths.push(path);
      const file = fs.readFileSync(path);
      const content = new TextDecoder().decode(file);
      const regExp = /^export\s+(\w*)\s*(\{?[\w,\d\s]*\}?)[\s(]/gmsi;
      const matches = content.matchAll(regExp);
      const result = [];
      for (const [, key, name] of matches) {
        if (key == "default") {
          const pathSplit = `${target}/${item}`.replace(".ts", "").split("/").reverse();
          const defaultName = pathSplit[0] == "index" ? pathSplit[1] : pathSplit[0];
          result.push(["default", defaultName]);
        } else if (["const", "let", "function", ""].includes(key)) {
          name.startsWith("{") ? result.push(...name.replace(/[,{}]|(default|[\w\d]+) as /g, "").trim().split(/[\s]/)) : result.push(name.trim());
        } else {
          console.log("autoImportConfigExtend:", key, name);
        }
      }
      importMap[`${alias}/${target}/${item}`.replace(".ts", "")] = result;
    }
  }
  return [importMap, ...presetNames];
};
const index = () => {
  return {
    name: "plugin-vue:importsListen",
    enforce: "post",
    handleHotUpdate({ file, server }) {
      for (const path of paths)
        file.endsWith(path) && server.restart();
    }
  };
};

exports["default"] = index;
exports.imports = imports;
